@@ -20,8 +20,9 @@ def dashport(stdscr):
     app.add_control("q", quit)
     app.add_control("KEY_DOWN", scroll_down)
     rows, cols = app.screen.getmaxyx()
-    app.title_bar(text=f"Title {app.cursor_x},{app.cursor_y}",
-                  align="top", color=256)
+    app.widget("title_bar",
+               text=f"Title {app.cursor_x},{app.cursor_y}",
+               align="top", color=256)
     for i in range(0, app.rows + 56):
         app.print(content=f"Line: {i} {app.cursor_y}")
 
